#!/bin/bash
# 用于部署更新脚本系统

Date=$(date +%F-%H-%M)
Pkg_Dir="/opt/jenkins/www/proj_pkg/${2}/${3}"
Dest="/opt/"
TYPE=$1
SERVER=${4}
PROJECT_NAME=$(echo $WORKSPACE | awk -F "/" '{print $NF}')
WORKSPACES=$(cd ..;pwd)
CURRENT_DIR=$(cd $(dirname $0); pwd)



function usage() {
  
  echo "Usage: "
  echo "  ./xxx.sh [Commands] [ 项目名称 ] [ansible thes server]"
  echo "  ./xxx.sh --help"
  echo
  echo "Management Commands: "
  echo "  dev      开发服更新部署"
  echo "  test     测试服更新部署"
  echo "  test     预发布服更新部署"
  echo "  prod     正式服更新部署"
  echo
}

#if [[ ${TYPE} == 'prod' ]];then
#  PROJECT_NAME=$(echo $PROJECT_NAME | awk -F "prod_" '{print $NF}')
#fi


Check_Ok() 
{
   if [ $? != 0 ]
   then
      echo "Error, Check the error log."
      exit 1
   fi
}

function tar_code () {

  # echo $WORKSPACE # 项目目录下
  echo "生成dist目录..."

  cd web

  if [ ! -d "node_modules" ]; then
    /usr/local/node/bin/npm install --registry=https://registry.npm.taobao.org
  fi

  /usr/local/node/bin/npm run build

  
  echo "正在打包完成..."
  /bin/tar -zcf ${Pkg_Dir}/${PROJECT_NAME}.tar.gz \
  --exclude=.git \
  --exclude=.env \
  --exclude=config \
  --exclude=docker-compose.yml \
  --exclude=web/node_modules \
  -C ${WORKSPACES} ${PROJECT_NAME}
  echo "打包完成..."
  
}

function scp_code() {

  ansible ${SERVER} -m shell -a 'if [ ! -d '${Dest}' ];then mkdir -p '${Dest}' ;fi'
  Check_Ok
  ansible ${SERVER} -m copy -a 'force=yes src='${Pkg_Dir}/${PROJECT_NAME}.tar.gz' dest='${Dest}''
  Check_Ok
  ansible ${SERVER} -m shell -a 'chdir='${Dest}' tar zxf '${PROJECT_NAME}'.tar.gz && rm -rvf '${PROJECT_NAME}'.tar.gz'

#   /bin/bash ${CURRENT_DIR}/initialize.sh ${SERVER} ${PROJECT_NAME} ${Dest}
#   # 清理tar包
  # rm -rvf ${Pkg_Dir}/${PROJECT_NAME}.tar.gz
}



case ${TYPE} in
 ceshi)
    tar_code
    ceshi_scp_code
    ;;
  dev|test|pre|prod)
    tar_code
    scp_code
    ;;
  help|--help|-h)
    usage
    ;;
    *)
	echo "No such command: 无效参数"
    usage
esac