#!/bin/bash
# 用于部署更新脚本系统

Date=$(date +%F-%H-%M)
Pkg_Dir="/opt/jenkins/www/proj_pkg/${2}/${3}"
Dest="/www/${2}/${3}"
TYPE=$1
SERVER=${4}
PROJECT_NAME=$(echo $WORKSPACE | awk -F "/" '{print $NF}')
WORKSPACES=$(cd ..;pwd)
CURRENT_DIR=$(cd $(dirname $0); pwd)
# PROJECT_NAME=$(pwd | awk -F "/" '{print $NF}')
# WORKSPACES='/opt/jenkins/jenkins_home/workspace/'


function usage() {
  
  echo "Usage: "
  echo "  ./xxx.sh [Commands] [items or old_items] [api or web or script] [ansible thes server]"
  echo "  ./xxx.sh --help"
  echo
  echo "Management Commands: "
  echo "  dev      开发服更新部署"
  echo "  test     测试服更新部署"
  echo "  test     预发布服更新部署"
  echo "  prod     正式服更新部署"
  echo
  echo "Management items or old_items: "
  echo "部署本项目是新项目还是老项目,老项目参数:old_items, 新项目参数:items"
  echo
  echo "Management api or web or script: "
  echo "后端是api 前端是web 脚本是script"
  echo
  echo "Management ansible thes server: "
  echo "ansible 远程主机名字"

}

#if [[ ${TYPE} == 'prod' ]];then
#  PROJECT_NAME=$(echo $PROJECT_NAME | awk -F "prod_" '{print $NF}')
#fi


Check_Ok() 
{
   if [ $? != 0 ]
   then
      echo "Error, Check the error log."
      exit 1
   fi
}

function tar_code () {

  # 针对web 打包部署
  for i in dev_server_web test_server_web pre_server_web prod_server_web
  do
    if [[ "${PROJECT_NAME}" == "${i}" ]];then

      echo "正在打包完成..."
      /bin/tar -zcf ${Pkg_Dir}/${PROJECT_NAME}.tar.gz \
      --exclude=*.svn \
      --exclude=.git \
      --exclude=backup/db_backup/data \
      --exclude=backup/crond/backmysql.sh \
      --exclude=wechat/welfareCenter/award/game_img \
      --exclude=view/Templates_c \
      --exclude=resource/weixin_qrcode \
      --exclude=items/config \
      --exclude=global/configure/replace.php \
      --exclude=wechat_account_recharge/global/configure/replace.php \
      --exclude=min_game/global/configure/replace.php \
      --exclude=game_box/v1.0/global/configure/replace.php \
      --exclude=data/lgame/packer \
      --exclude=config_auto.php \
      -C ${WORKSPACES} ${PROJECT_NAME}
      echo "打包完成...web"
      return 1
    fi
  done

  # 通用打包部署
  # echo $WORKSPACE # 项目目录下
  echo "正在打包完成..."
  /bin/tar -zcf ${Pkg_Dir}/${PROJECT_NAME}.tar.gz \
  --exclude=thinkphp/library/think/cache/driver/Redis.php \
  --exclude=.git \
  --exclude=.env \
  --exclude=config \
  --exclude=items/config \
  -C ${WORKSPACES} ${PROJECT_NAME}
  echo "打包完成...xxx"
  
}

function scp_code() {

  ansible ${SERVER} -m shell -a 'if [ ! -d '${Dest}' ];then mkdir -p '${Dest}' ;fi'
  Check_Ok
  ansible ${SERVER} -m copy -a 'force=yes src='${Pkg_Dir}/${PROJECT_NAME}.tar.gz' dest='${Dest}''
  Check_Ok
  ansible ${SERVER} -m shell -a 'chdir='${Dest}' tar zxf '${PROJECT_NAME}'.tar.gz  && \
  rm -rf '${PROJECT_NAME}'.tar.gz'
  

  # 清理tar包
  /bin/bash ${CURRENT_DIR}/initialize.sh ${SERVER} ${PROJECT_NAME} ${Dest}
  rm -rvf ${Pkg_Dir}/${PROJECT_NAME}.tar.gz
}



case ${TYPE} in
 ceshi)
    tar_code
    ceshi_scp_code
    ;;
  dev|test|pre|prod)
    tar_code
    scp_code
    ;;
  help|--help|-h)
    usage
    ;;
    *)
	echo "No such command: 无效参数"
    usage
esac
